fileName<-'~/Documents/Cathy/Neuroscience papers/capstone/Testing/multiple/testcase3varsProg/JF038.dat.txt'}

CATCosinor(TimeCol=1,Y=c(2,3,4), Components=2, window="noFilt", RefDateTime="12",  timeFormat="%Y%m%d%H%M", RangeDateTime=list(Start=0, End=0), Units='hour', dt=0, Progressive=list(Span=0, Increment=0), Period=list(Set=c(24,24.8),Start=0,Increment=1,End=0),header=F, Skip=0, Colors="BW",Graphics="pdf",Output=list(Txt=F,Dat=T,TxtAmp=F,Doc=T,HeatMap=F,LineGraphs=F),Console=F,Debug=FALSE,fileName=fileName) {
  # Header:  T/F to indicate if the file has a header
  #%H represents 0-23, so have to have numeric time in Excel sheet, and numeric time rep option
  # Dates are represented as the number of days since 1970-01-01
  #strptime reads in characters and produces POSIX formatted date/time;  strptime accepts the format of date being read -- output is always POSIX
  #use format wrapped around POSIX to output a date in a different format than POSIX
  #POSIXct: This class stores a date in a vector, as the number of seconds passed since January, 1st, 1970 at 1AM
  #POSIXlt: This class stores a date in a list: (day of the month, day of the week, day of the year, month, year, time zone, hour, minute, second).
  # TimeCol:  Column where time is found
  # Y:  Data to be analyzed
  # Components:  Default=1.  Indicates if this is a single or multiple component cosinor analysis, where the number of components is specified (>0).  
  # window:      Data will be convolved with a window:  hanning, hamming, bartlett, blackman.  Default="noFilt"
  # RefDateTime:  Date used as reference, and subtracted from all data dates, to make the number smaller.  **Must be in the same time zone!!!!!**
  #             if RefDateTime = 0, use the 1st date of the data as the RefDateTime 
  #             if RefDateTime = 12, use midnight of the same day as the data starts 
  # timeFormat:   RefDateTime and the time in the data file should both use the same date/time format.   Can be "numeric" or "%Y%m%d%H%M"
  #             i.e., "%Y%m%d%H%M", or if = "numeric", time column in data file can be simple numbers (0 - 99999...)
  #              ToDo:  modify to use alternate time formats
  # RangeDateTime
  #      $Start:  Analysis is started at this date/time.  May be before 1st data date.
  #             if Start = 0, use the 1st time in the data set
  #             if Start = 12 use Midnight at the start of the 1st date of the data as the StartDate 
  #        $End:    Analysis ends at this date/time.  May be after last data date.
  #             if End = 0, use the last time in the data set
  #             if End = 12 use the midnight at the end of the last date of the data as the EndDate   
  # Units:        Units (Hour, Year, Week or Day) for Span and Increment arguments, as well as Period arguments
  #               ToDo:  modify to use units other than Hours
  # Progressive
  #      $Span : number of Days, Wks or Yrs in a subset of full data  -- multiple spans calculated
  #               If 0, assumes no progession, Span is set to the full dataset length, and Increment = full data set  
  #  $Increment: number of Days, Wks or Yrs  (uses same unit as set for Span) to shift between span analyses
  #               If 0, assumes no progession, Span is set to the full dataset length, and Increment = full data set 
  # Period
  #       $End : Last (and smallest) period to calculate, in units of Days, Wks or Yrs (as set by Units)
  #               Defaults to 2;  (1 is too small) 0 is invalid  -- says use default
  #  $Increment : Increment to starting period, in units of Days, Wks or Yrs (as set by Units)
  #               Defaults to 1;   0 is invalid  -- says use default
  #     $Start : First (and largest) period to calculate, in units of Days, Wks or Yrs (as set by Units);  (Span/1)
  #               0 is Default: full time range analyzed [in hours?] (RangeDateTime$End-RangeDateTime$Start)= MyData_length; or if progressive, Span/1;     
  #      $Set :  Overrides Period$Start and $Increment, to specify a specific set of periods to analyze (as set by Units).  If $End will determine ending period 
  #              Can be in the format of a single number, or an array:  c(1,2,3) or c(8,12:24)
  #              When Components=1, each period specified in the vector will be assessed by cosinor independently.
  #              When parameter Components is >1, Period$Set must have a correspondig number of components, which assessed together in a multiple component cosinor.
  #              If 0, a series of periods are analyzed (spectrum) according to Period$Start, $Increment, $End (or their default value, if not specified)
  #              When 0, only the maximum period, or the maximum period per span, from a spectrum is displayed on the graphics file.
  #              Otherwise, all periods are displayed on the graphic 
  #  Colors       "Heat" renders the heat map in colors;  "BW" renders the heatmap in grayscale
  #  Graphics    Possible values:  jpg, pdf, tif, png
  #  Output      Txt will generate a comma delimited .txt document containing output,Doc will generate a nicely formatted Word doc
  #                  HeatMap will generate a heatmap, but only when more than one period is specified for a progressive analysis
  #                 LineGraphs will generate a set of graphs plotting MESOR, Amplitude, Acrophase over time--too many when you do a progressive
  # dt           When equidistant data, dt indicates the sampling interval.  If dt =0, no periodogram is done.
  #                  Data is assumed to be equidistant when this is nonzero
  #   source('~/Documents/Cathy/Neuroscience papers/capstone/Bartolomucci/chrono data/R-functions/CatPeri/CatPeri.R')    #  Add for MAC
  #   source('~/Documents/Cathy/Neuroscience papers/capstone/Chronobiology/CosinorR/Cosinor-Hamming-sine/CatWindow.R')
  #   source('~/Documents/Cathy/Neuroscience papers/capstone/Bartolomucci/chrono data/R-functions/CatBin/CatBin.R')
  #   source('~/Documents/Cathy/Neuroscience papers/capstone/Chronobiology/CosinorR/ANOVA/CatPlexi.R')
  #source('E:/R/Cosinor May1-2013/periCosinor.R')     # Add for PC
  #library(season)
  #functionName<-"CosinorSpan_PeriVsCosFiltCATmulti2closeVars"
  #tz="GMT"
  
#   if (call==TRUE){    #  chg TimeCol 1, dt 2/60, Y 2, timeFormat<-"%Y/%m/%d %H:%M:%S", Components ?, line 210 less numerics    
#     #  or chg TimeCol 2, dt 0, Y 4, timeFormat<-"%Y%m%d%H%M" line 210 add numerics 
#     header<-F          #These lines are needed to set variables when not run as a function
#     TimeCol<-1          #c(1,2)    ##### for mouse data
#     Components<-2
#     dt<-(0)
#     Y<-c(2,3,4)           #### change for mouse data  -- use exact column number from file 
#     Skip=0
#     RefDateTime<- "12"              #"200910180000"    for mine: "201302030000"    "12"  "0"  
#     RangeDateTime<-list(Start="0", End="0")
#     timeFormat<-"%Y%m%d%H%M"      #"%Y/%m/%d %H:%M:%S"                        #numeric"
#     Units<-'Hour'              #  Hour, Day, Week, Year
#     Plex<-TRUE
#     foldLen<-24
#     Progressive<-list(Span=0, Increment=0)            #  Progressive spans of time   144,8   1807.5
#     Period <-list(Set=c(24,24.8),Start=0,Increment=1,End=0)     #  format option:  Set=c(24,26,8)   
#     Debug<-FALSE
#     Colors="BW"       #"terrain"                  #Heat"   #BW
#     #terrain.colors(n, alpha = 1)
#     #topo.colors(n, alpha = 1)
#     Output=list(Txt=F,Dat=T,TxtAmp=F,Doc=T,HeatMap=F,LineGraphs=F)
#     
#     Graphics<-"pdf"
#     Console<-F
    
    #timeFormat<-"%Y%m%d%H%M"
    #fileName<-'~/Documents/Cathy/Neuroscience papers/capstone/Chronobiology/CosinorR/Data/clgi001.dat'}  #  Add for MAC
    #fileName<-'E:\\R\\CLGi001.pr0'}            # Add for PC
    #fileName<-'~/Documents/Cathy/Neuroscience papers/capstone/Chronobiology/CosinorR/Data/FH3h1wk.dat.txt'}
    #fileName<-'~/Documents/Cathy/Neuroscience papers/capstone/Chronobiology/CosinorR/Data/Signal10-20.txt'}
    #fileName<-'~/Documents/Cathy/Neuroscience papers/capstone/Testing/multiple/activity stress c57--stress copy2-short.txt'}
    #fileName<-'~/Documents/Cathy/Neuroscience papers/capstone/Testing/multiple/CG140129.pr0'}
    #fileName<-'~/Documents/Cathy/Neuroscience papers/capstone/Testing/multiple/testcasebliss/BlissT17-1.dat.txt'}
    
    #fileName<-'~/Documents/Cathy/Neuroscience papers/capstone/Testing/multiple/testcase3varsProg/JF002.dat.txt'}
    